"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DocumentChunkTypedDict(TypedDict):
    id: str
    text: str
    index: NotRequired[int]


class DocumentChunk(BaseModel):
    id: str

    text: str

    index: Optional[int] = -1
